# Youtube Enhanced

The simplest way to interact with Youtube.

This library will manage (and create) a 'token_files' folder and a 'client-secret.json' file that are needed to work with Youtube platform. These elements will be created when you successfully connect and allow Youtube to connect with this library. These folder and file will be in your project parent folder.